@@ -16,6 +16,13 @@ class DistInstance(nn.Module, abc.ABC):
         """
         pass
 
+    @abc.abstractmethod
+    def deterministic_sample(self) -> torch.Tensor:
+        """
+        Return the most probable sample from this distribution.
+        """
+        pass
+
     @abc.abstractmethod
     def log_prob(self, value: torch.Tensor) -> torch.Tensor:
         """
@@ -59,8 +66,11 @@ class GaussianDistInstance(DistInstance):
         sample = self.mean + torch.randn_like(self.mean) * self.std
         return sample
 
+    def deterministic_sample(self):
+        return self.mean
+
     def log_prob(self, value):
-        var = self.std ** 2
+        var = self.std**2
         log_scale = torch.log(self.std + EPSILON)
         return (
             -((value - self.mean) ** 2) / (2 * var + EPSILON)
@@ -74,7 +84,7 @@ class GaussianDistInstance(DistInstance):
 
     def entropy(self):
         return torch.mean(
-            0.5 * torch.log(2 * math.pi * math.e * self.std ** 2 + EPSILON),
+            0.5 * torch.log(2 * math.pi * math.e * self.std**2 + EPSILON),
             dim=1,
             keepdim=True,
         )  # Use equivalent behavior to TF
@@ -113,6 +123,9 @@ class CategoricalDistInstance(DiscreteDistInstance):
     def sample(self):
         return torch.multinomial(self.probs, 1)
 
+    def deterministic_sample(self):
+        return torch.argmax(self.probs, dim=1, keepdim=True)
+
     def pdf(self, value):
         # This function is equivalent to torch.diag(self.probs.T[value.flatten().long()]),
         # but torch.diag is not supported by ONNX export.
@@ -212,6 +225,7 @@ class MultiCategoricalDistribution(nn.Module):
         # We do -1 * tensor + constant instead of constant - tensor because it seems
         # Barracuda might swap the inputs of a "Sub" operation
         logits = logits * allow_mask - 1e8 * block_mask
+
         return logits
 
     def _split_masks(self, masks: torch.Tensor) -> List[torch.Tensor]:
